@@ -1,22 +1,68 @@
 test_that("defaul template", {
   x <- read_pptx()
-  expect_equal(length( x ), 0)
+  expect_equal(length(x), 0)
   expect_true(file.exists(x$package_dir))
 })
 
+
 test_that("console printing", {
+  opts <- options(cli.num_colors = 1) # suppress colors for error message check
+  on.exit(options(opts))
+
   x <- read_pptx()
+  layouts <- layout_summary(x)$layout
+
+  # 1 slide
   x <- add_slide(x, "Title and Content", "Office Theme")
   x <- ph_with(x, "Hello world", location = ph_location_type(type = "body"))
-  expect_output(print(x), "pptx document with 1 ")
+  output_print <- capture.output({
+    # capture layout dataframe
+    output_cli <- cli::cli_fmt(print(x)) # capture cli info lines
+  })
+  expect_true(any(grepl("pptx document with 1 slide", output_cli)))
+  output_shows_layout <- vapply(
+    layouts,
+    function(l) any(grepl(l, output_print)),
+    logical(1)
+  )
+  expect_true(all(output_shows_layout))
+
+  # 2 slides
+  x <- add_slide(x, "Title and Content", "Office Theme")
+  x <- ph_with(x, "Hello world", location = ph_location_type(type = "body"))
+  output_print <- capture.output({
+    output_cli <- cli::cli_fmt(print(x))
+  })
+  expect_true(any(grepl("pptx document with 2 slides", output_cli)))
+
+  # 2 slides + default layout
+  x <- layout_default(x, "Title and Content")
+  output_print <- capture.output({
+    output_cli <- cli::cli_fmt(print(x))
+  })
+  expect_true(any(grepl("(*) = Default layout", output_cli)))
+  output_shows_layout <- vapply(
+    layouts,
+    function(l) any(grepl(l, output_print)),
+    logical(1)
+  )
+  expect_true(all(output_shows_layout))
+
+  # default layout removed again
+  x <- layout_default(x, NULL)
+  output_print <- capture.output({
+    output_cli <- cli::cli_fmt(print(x))
+  })
+  expect_false(any(grepl("(*) = Default layout", output_cli)))
 })
 
+
 test_that("check extention and print document", {
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
   x <- ph_with(x, "Hello world", location = ph_location_type(type = "body"))
   print(x, target = "print.pptx")
-  expect_true( file.exists("print.pptx") )
+  expect_true(file.exists("print.pptx"))
 
   expect_error(print(x, target = "print.pptxxx"))
 })
@@ -30,14 +76,17 @@ test_that("check template", {
 
   expect_silent(x <- read_pptx(path = "template.pptx"))
   x <- add_slide(x, "Title and Content", "Office Theme")
-  x <- ph_with(x, "Hello world again", location = ph_location_type(type = "body"))
+  x <- ph_with(
+    x,
+    "Hello world again",
+    location = ph_location_type(type = "body")
+  )
   print(x, target = "example.pptx")
 
   expect_equal(length(x), 2)
 })
 
 
-
 test_that("slide remove", {
   x <- read_pptx()
   x <- add_slide(x, "Title and Content", "Office Theme")
@@ -55,7 +104,7 @@ test_that("slide remove", {
   expect_equal(length(x), 1)
 
   sm <- slide_summary(x)
-  expect_equal(sm[1,]$text, "Hello world 2")
+  expect_equal(sm[1, ]$text, "Hello world 2")
 })
 
 test_that("slide remove with rm_images", {
@@ -63,7 +112,7 @@ test_that("slide remove with rm_images", {
   ext_img <- external_img(img.file)
 
   x <- read_pptx()
-  x <- add_slide(x)
+  x <- add_slide(x, "Title and Content")
   x <- ph_with(x, ext_img, location = ph_location_type())
   filename <- print(x, target = tempfile(fileext = ".pptx"))
 
@@ -96,13 +145,12 @@ test_that("ph remove", {
 
 test_that("cursor is incremented as expected", {
   x <- read_pptx()
-  for(i in 1:11){
+  for (i in 1:11) {
     x <- add_slide(x, "Title Slide", "Office Theme")
     x <- ph_with(x, i, location = ph_location_type(type = "ctrTitle"))
   }
-  expect_equal(nrow( slide_summary(x, 11) ), 1 )
-  expect_equal(x$slide$get_slide(11)$name(), "slide11.xml" )
-
+  expect_equal(nrow(slide_summary(x, 11)), 1)
+  expect_equal(x$slide$get_slide(11)$name(), "slide11.xml")
 })
 
 test_that("annotate base template", {
@@ -112,8 +160,15 @@ test_that("annotate base template", {
 test_that("no master do not generate an error", {
   x <- read_pptx("docs_dir/no_master.pptx")
   x <- add_slide(x, layout = "Page One", master = "Office Theme")
-  x <- try(ph_with(x, i, value = "graphic title",
-               location = ph_location_type(type="body")), silent = TRUE)
+  x <- try(
+    ph_with(
+      x,
+      i,
+      value = "graphic title",
+      location = ph_location_type(type = "body")
+    ),
+    silent = TRUE
+  )
   expect_s3_class(x, "rpptx")
 })
 
